# agecal
This library provides 
1. say "Hi Everyone"
2. Compare age between user and I whether who is younger or older
   - It takes user's age as an input.

## Installation
```pip install mickzaa-age```

## How to use it?
```import agecal```<br />
```from agecal import greeting```<br />
```from agecal import compareage```<br />

### To print "Hi everyone"
```greeting.sayHi()``` 

### Comparing the age between user and I. 
### It takes user's age as an input and print younger or older as an output.
```compareage.compare_my_age()``` 

## License
Copyright 2021 Mickzaa